@@ -4,7 +4,7 @@ Main interface for amp service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_amp import (
         Client,
         ListRuleGroupsNamespacesPaginator,
@@ -14,10 +14,8 @@ Usage::
         WorkspaceDeletedWaiter,
     )
 
-    session = boto3.Session()
-
-    client: PrometheusServiceClient = boto3.client("amp")
-    session_client: PrometheusServiceClient = session.client("amp")
+    session = Session()
+    client: PrometheusServiceClient = session.client("amp")
 
     workspace_active_waiter: WorkspaceActiveWaiter = client.get_waiter("workspace_active")
     workspace_deleted_waiter: WorkspaceDeletedWaiter = client.get_waiter("workspace_deleted")
