@@ -1,7 +1,7 @@
 """
 Type annotations for amp service client waiters.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amp/waiters.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_amp/waiters/)
 
 Usage::
 
@@ -31,24 +31,24 @@ __all__ = ("WorkspaceActiveWaiter", "WorkspaceDeletedWaiter")
 class WorkspaceActiveWaiter(Boto3Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amp.html#PrometheusService.Waiter.WorkspaceActive)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amp/waiters.html#workspaceactivewaiter)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_amp/waiters/#workspaceactivewaiter)
     """
 
-    def wait(self, *, workspaceId: str, WaiterConfig: WaiterConfigTypeDef = ...) -> None:
+    def wait(self, *, workspaceId: str, WaiterConfig: "WaiterConfigTypeDef" = ...) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amp.html#PrometheusService.Waiter.WorkspaceActive.wait)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amp/waiters.html#workspaceactivewaiter)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_amp/waiters/#workspaceactivewaiter)
         """
 
 
 class WorkspaceDeletedWaiter(Boto3Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amp.html#PrometheusService.Waiter.WorkspaceDeleted)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amp/waiters.html#workspacedeletedwaiter)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_amp/waiters/#workspacedeletedwaiter)
     """
 
-    def wait(self, *, workspaceId: str, WaiterConfig: WaiterConfigTypeDef = ...) -> None:
+    def wait(self, *, workspaceId: str, WaiterConfig: "WaiterConfigTypeDef" = ...) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amp.html#PrometheusService.Waiter.WorkspaceDeleted.wait)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_amp/waiters.html#workspacedeletedwaiter)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_amp/waiters/#workspacedeletedwaiter)
         """
